#[non_exhaustive]pub enum Error {
CurrentDir(Error),
ReadLockfile(Error),
ParseLockfile(Error),
UnexpectedLockfileContent,
}Expand description
The error type for tree functionality.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CurrentDir(Error)
Error when the current directory cannot be determined.
ReadLockfile(Error)
Error when the pnpm-lock.yaml file cannot be read.
ParseLockfile(Error)
Error when the pnpm-lock.yaml file cannot be parsed.
UnexpectedLockfileContent
Error when the lockfile content could not be understood. Currently, this is only when the snapshot key cannot be split into a package name and version.