pub struct Snapshot {
pub optional: bool,
pub dependencies: HashMap<String, String>,
pub optional_dependencies: HashMap<String, String>,
pub transitive_peer_dependencies: Vec<String>,
}Expand description
A snapshot represents a package in the store.
Fields
optional: boolIf the package is only used in optional dependencies.
dependencies: HashMap<String, String>The resolved dependencies of the package, a map from package name to qualified version.
...
snapshots:
foo@1.2.3:
dependencies:
bar: 4.5.6
bar@4.5.6: {}
...optional_dependencies: HashMap<String, String>As with dependencies, but for optional dependencies (including optional peer
dependencies).
transitive_peer_dependencies: Vec<String>The package names of peer dependencies of the transitive package dependencies, excluding direct peer dependencies.